@@ -93,6 +93,29 @@ gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
 	return TRUE;
 }
 
+void secuencer_sync_buttons_to_pitch_and_tempo() {
+	int starting_tempo = jammo_sequencer_get_tempo(static_sequencer);
+	//printf("starting_tempo %d\n",starting_tempo);
+	ClutterActor* button;
+	gchar* name_button="";
+	if(starting_tempo== 130)       name_button="tempo-button-fast";
+	else if(starting_tempo== 110)  name_button="tempo-button-normal";
+	else if(starting_tempo==90)    name_button="tempo-button-slow";
+
+	button =jammo_get_actor_by_id(name_button);
+	if (button)
+		tangle_button_set_selected(TANGLE_BUTTON(button),TRUE);
+
+	const gchar* starting_pitch = jammo_sequencer_get_pitch(static_sequencer);
+	if(strcmp(starting_pitch,"G")==0)       name_button="pitch-button-high";
+	else if(strcmp(starting_pitch,"D")==0)  name_button="pitch-button-normal";
+	else if(strcmp(starting_pitch,"A")==0)  name_button="pitch-button-low";
+
+	button =jammo_get_actor_by_id(name_button);
+	if (button)
+		tangle_button_set_selected(TANGLE_BUTTON(button),TRUE);
+}
+
 //show-completed callback (=animation is ready)
 static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 	g_signal_handlers_disconnect_by_func(levelview, levelview_loaded, NULL);
@@ -117,6 +140,8 @@ static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 		gchar* task_name = g_strdup_printf("%s-task1.json",levelname);
 		jammo_game_level_start_task(game_level,task_name);
 		g_free(task_name);
+
+		secuencer_sync_buttons_to_pitch_and_tempo();
 	}
 
 }
@@ -151,6 +176,9 @@ void start_fullsequencer_gui(ClutterActor* levelview)
 }
 
 void return_to_fullsequencer_gui(){
+	//At least backing-track-selection could change pitch/tempo
+	secuencer_sync_buttons_to_pitch_and_tempo();
+
 	clutter_actor_show(CLUTTER_ACTOR(jammo_mentor_get_default()));
 	clutter_actor_show(current_levelview);
 }
