@@ -46,6 +46,10 @@ static quad cannot_fail_lists[] = {
 	{ 4,6,9,4     },
 	{ 9,9,8,-1    }
 };
+static int length_of_rhythms=0;
+static int length_of_melodics=0;
+static int length_of_harmonics=0;
+static int length_of_effects=0;
 
 gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 
@@ -211,13 +215,11 @@ static void rotate_loop_for_amount(ClutterActor* wheel, gint amount) {
 /*
 Will rotate wheel so target_slot is center of wheel.
 slot means index on list.
--1 means 'do not rotate this at all'
 */
 static void rotate_to_place(ClutterActor* wheel, gint target_slot) {
-	if (target_slot==-1)
-		return;
 	ClutterAction* scroll_action = tangle_actor_get_action_by_type(wheel,TANGLE_TYPE_SCROLL_ACTION);
 
+	target_slot-=2; //unless target will be in most upper slot
 	//printf("current_slot = %d, target pixel='%f'\n",current_slot,target);
 	tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 750, "offset-y", target_slot*92.0, NULL);
 }
@@ -237,6 +239,12 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 	cem_add_to_log(message,J_LOG_DEBUG);
 	g_free(message);
 
+	//-1 means last element of corresponding list
+	if (combo.r==-1) combo.r=length_of_rhythms-1;
+	if (combo.m==-1) combo.m=length_of_melodics-1;
+	if (combo.h==-1) combo.h=length_of_harmonics-1;
+	if (combo.e==-1) combo.e=length_of_effects-1;
+
 	rotate_to_place(rhytmical_sample_looper, combo.r);
 	rotate_to_place(melodical_sample_looper, combo.m);
 	rotate_to_place(harmonical_sample_looper, combo.h);
@@ -244,7 +252,7 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 }
 
 
-//There will be some logic
+//This is just random.
 void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",J_LOG_USER_ACTION);
 	GRand *random_gen = g_rand_new();
@@ -282,10 +290,6 @@ static void sample_button_drag_begin(JammoSampleButton* sample_button, gpointer
 	sequencer_change_to_sequencer_view(NULL,NULL);
 }
 
-static int length_of_rhythms=0;
-static int length_of_melodics=0;
-static int length_of_harmonics=0;
-static int length_of_effects=0;
 
 typedef struct {
 	const gchar* image;
@@ -421,6 +425,7 @@ static samplebutton_tuple rhythms[] = {
 	{"wheel_game/tabla.png","wheel_game/Rh_tabla07_$t_44_1.ogg"},
 	{"wheel_game/tabla.png","wheel_game/Rh_tabla08_$t_44_1.ogg"},
 	{"wheel_game/tabla.png","wheel_game/Rh_tabla09_$t_44_1.ogg"},
+	{"wheel_game/empty.png",NULL}, //Keep this last. used for cannot-fail
 	{NULL,NULL}
 };
 
@@ -596,6 +601,7 @@ static samplebutton_tuple melodics[] = {
 	{"wheel_game/cello.png", "wheel_game/Me_cello06_$t_$p_44_2.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Me_cello07_$t_$p_44_2.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Me_cello08_$t_$p_44_1.ogg"},
+	{"wheel_game/empty.png",NULL}, //Keep this last. used for cannot-fail
 	{NULL,NULL}
 };
 
@@ -679,6 +685,7 @@ static samplebutton_tuple harmonics[] = {
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar07_$t_$p_44_2.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar09_$t_$p_34_2.ogg"},
 	{"wheel_game/acoustic_guitar.png", "wheel_game/Ha_acguitar10_$t_$p_34_2.ogg"},
+	{"wheel_game/empty.png",NULL}, //Keep this last. used for cannot-fail
 	{NULL,NULL}
 };
 
@@ -718,6 +725,7 @@ static samplebutton_tuple effects[] = {
 	{"wheel_game/hamba_vocal.png", "wheel_game/Fx_SiyaHambaVocal3_$t_$p_44_4.ogg"},
 	{"wheel_game/synthpad.png", "wheel_game/Fx_filterpulse_$t_44_2.ogg"},
 	{"wheel_game/synthpad.png", "wheel_game/Fx_synthpulse_$t_44_1.ogg"},
+	{"wheel_game/empty.png",NULL}, //Keep this last. used for cannot-fail
 	{NULL,NULL}
 };
 
@@ -783,11 +791,16 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 		int loop_id = counter+loop_type;
 
+
 		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
 		g_signal_connect(sample_button,"drag-begin", G_CALLBACK(sample_button_drag_begin),NULL);
 
+		//sound==NULL -> this is not really samplebutton: it can't be dragged at all.
+		if (new_button.sound==NULL)
+			g_object_set(sample_button,"drag-threshold-x",10000,NULL); //No dragging
+		else
+			jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), loop_id);
 
-		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), loop_id);
 		g_free(full_image);
 		g_free(full_sound);
 
