@@ -2,6 +2,12 @@
 #ifndef _CONFIGURE_H_
 #define _CONFIGURE_H_
 
+#include <glib.h>
+//get_jammo_directory is writable place for logs, passwords and saved singings/compositions
+gchar* configure_get_jammo_directory();
+gchar* configure_get_singings_directory();
+gchar* configure_get_compositions_directory();
+
 /**
  * Defines default folders.
  */
@@ -13,22 +19,16 @@
 
 
 
-//JAMMO_DIRECTORY is for saving users files (and log files)
+
 //AUDIO_DIR is only for audible-data
 
-//N900 has very limited /tmp space. -> we can't use it at all
 //N900 has not enough space on /opt for audio data -> put them to MyDocs
 #ifdef N900
-#define JAMMO_DIRECTORY "/home/user/MyDocs/jammo"
 #define AUDIO_DIR "/home/user/MyDocs/jammo_data"
 #else
-#define JAMMO_DIRECTORY "/tmp/jammo" //TODO: make same permanent place
 #define AUDIO_DIR DATA_DIR //NOTE: same than DATA_DIR
 #endif
 
-#define COMPOSITIONS_DIRECTORY JAMMO_DIRECTORY "/compositions"
-#define SINGINGS_DIRECTORY JAMMO_DIRECTORY "/singings"
-
 //These are not heavily used
 #define WIDTH_OF_WINDOW 800
 #define HEIGHT_OF_WINDOW 480
